
import React, { useEffect, useState } from "react";
import axios from "axios";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import './index.css';
import { Header } from "../../Components/Header";
import { ImageSlide2 } from "../../Components/imageslide2";
import { Footer } from "../../Components/footer";
import moment from "moment";

// breadcrums images
import image from "../../Assests/Images/darkbread.jpg";
import image2 from "../../Assests/Images/line.png";
import image3 from "../../Assests/Images/sprade-light.png";

//bread-crums image end

export const WishPage = () => {


    const [wishlists, setWishlists] = useState([]);

    React.useEffect(() => {
        const fetchWishlists = async () => {
            try {
                const token = localStorage.getItem("token"); // Token Storage থেকে আনুন
                const response = await axios.get("http://localhost:8000/api/wishlists", {
                    headers: {
                        Authorization: `Bearer ${token}`,
                    }
                });
                if (response?.data?.success) {
                    const wishlistData = response.data.data;
                    setWishlists(wishlistData);
                }
            } catch (error) {
                console.error("Error fetching wishlists:", error);
            }
        };
        fetchWishlists();

    }, []);


    const handleRemove = async (id) => {
        try {
            const token = localStorage.getItem("token");
            const response = await axios.delete(`http://localhost:8000/api/wishlists/${id}`, {
                headers: {
                    Authorization: `Bearer ${token}`,
                }
            });

            if (response.data.success) {
                // Remove item from state
                setWishlists(prev => prev.filter(item => item.id !== id));
            }
        } catch (error) {
            console.error("Failed to delete wishlist item:", error);
        }
    };




    return (
        <>
            <div className="donationpage">
                <Header />
                <div className="breadcrums">
                    <div className="breadcrums-imgbx">
                        <img src={image} alt="" />
                    </div>
                    <div className="breadcrums-content">
                        <h1>Wishlist</h1>
                    </div>

                    <div className="breadcrums-front-img">
                        <img src={image2} alt="" />
                    </div>

                    <div className="stiker">
                        <img src={image3} alt="" />
                    </div>

                    <div className="bread-crums-main-content">
                        <div className="sub-content">
                            <a href="">Home</a>
                            <span>/</span>
                            <a href="">Wishlist</a>
                        </div>
                    </div>
                </div>
                <div style={{ padding: "0 10%", marginBottom: "50px" }}>
                    <div className="aid-control">
                        <h1>My Wishes </h1>

                        <table style={{ minHeight: "300px" }}>
                            <thead>
                                <tr>
                                    <th>SL No</th>
                                    <th>Product Name</th>
                                    <th>Price</th>
                                    <th>Image</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                {wishlists.map((item, index) => (
                                    <tr key={item.id}>
                                        <td>{index + 1}</td>
                                        <td>{item.product?.title || "N/A"}</td>
                                        <td>{item.product?.price ? `৳${item.product.price}` : "N/A"}</td>
                                        <td>
                                            {item.product?.image ? (
                                                <img
                                                    src={`http://localhost:8000/${item.product.image}`}
                                                    alt={item.product.title}
                                                    style={{ width: "70px", height: "70px", objectFit: "cover" }}
                                                />
                                            ) : (
                                                "No Image"
                                            )}
                                        </td>

                                        <td>
                                            <button className="btn btn-danger" onClick={() => {
                                                if (window.confirm("Are you sure you want to remove this item?")) {
                                                    handleRemove(item.id);
                                                }
                                            }}>Remove</button>
                                        </td>
                                    </tr>
                                ))}
                            </tbody>


                        </table>


                    </div>



                </div>
                <ImageSlide2 />
                <Footer />
            </div>
        </>
    );
}
